@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OGAM import H2OGAM
 
@@ -30,10 +30,9 @@ class H2OGAMClassifier(H2OGAM):
                  betaConstraints=None,
                  gamCols=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -42,6 +41,7 @@ class H2OGAMClassifier(H2OGAM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
@@ -75,13 +75,9 @@ class H2OGAMClassifier(H2OGAM):
                  computePValues=False,
                  removeCollinearCols=False,
                  numKnots=None,
-                 splineOrders=None,
-                 splinesNonNegative=None,
                  scale=None,
                  bs=None,
                  keepGamCols=False,
-                 standardizeTpGamCols=False,
-                 scaleTpPenaltyMat=False,
                  knotIds=None,
                  modelId=None,
                  nfolds=0,
@@ -107,7 +103,6 @@ class H2OGAMClassifier(H2OGAM):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OGAMClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
